<?php

/**
 * @package Vimeo Embedder BBC Mod
 * @version 2.2
 * @Modified for Vimeo use by Pipke
 * @copyright Copyright (C) 2012 - 2014, Pipke
 * @license http://www.mozilla.org/MPL/MPL-1.1.html
 */

/*
 * Version: MPL 1.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is http://missallsunday.com code.
 *
 * The Initial Developer of the Original Code is
 * Jessica Gonzlez.
 * Portions created by the Initial Developer are Copyright (C) 2011, 2012, 2013
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 * Pipke
 *
 */ 

if (!defined('SMF'))
	die('Hacking attempt...');
	
function vimeo_bbc_admin(&$areas)
{
	global $txt;

	loadLanguage('vimeo');

	$areas['config']['areas']['modsettings']['subsections']['vimeobbc'] = array($txt['vimeo_settings_title']);
}

function vimeo_bbc_settings(&$sub_actions)
{
	global $context;

	$sub_actions['vimeobbc'] = 'vimeo_postSettings';
	$context[$context['admin_menu_name']]['tab_data']['tabs']['vimeo'] = array();
}

function vimeo_postSettings($return_config = false)
{
	global $context, $scripturl, $txt;

	$config_vars = array(
		array('desc', 'vimeo_settingsnote'),
		array('check', 'vimeo_master', 'subtext' => $txt['vimeo_master_sub']),
		array('check', 'vimeo_autoplay', 'subtext' => $txt['vimeo_autoplay_sub']),
		array('check', 'vimeo_badge', 'subtext' => $txt['vimeo_badge_sub']),
		array('check', 'vimeo_byline', 'subtext' => $txt['vimeo_byline_sub']),
		array('check', 'vimeo_loop', 'subtext' => $txt['vimeo_loop_sub']),
		array('check', 'vimeo_portrait', 'subtext' => $txt['vimeo_portrait_sub']),
		array('check', 'vimeo_video_title', 'subtext' => $txt['vimeo_video_title_sub']),
		array('int', 'vimeo_color', 'subtext' => $txt['vimeo_color_sub'],'preinput' => '&#35;', 'size' => 6),
		array('int', 'vimeo_video_width', 'subtext' => $txt['vimeo_video_width_sub'], 'size' => 3),
		array('int', 'vimeo_video_height', 'subtext' => $txt['vimeo_video_height_sub'], 'size' => 3),
	);

	if ($return_config)
		return $config_vars;

	$context['post_url'] = $scripturl . '?action=admin;area=modsettings;save;sa=vimeobbc';
	$context['settings_title'] = $txt['vimeo_settings_title'];

	if (empty($config_vars))
	{
		$context['settings_save_dont_show'] = true;
		$context['settings_message'] = '<div align="center">' . $txt['modification_no_misc_settings'] . '</div>';

		return prepareDBSettingContext($config_vars);
	}

	if (isset($_GET['save']))
	{
		checkSession();
		$save_vars = $config_vars;
		saveDBSettings($save_vars);
		redirectexit('action=admin;area=modsettings;sa=vimeobbc');
	}

	prepareDBSettingContext($config_vars);
}
	

	function vimeo_bbc_add_code(&$codes)
	{
		global $modSettings;

		if (empty($modSettings['vimeo_master']))
			return;

		$codes[] = array(
			'tag' => 'vimeo',
			'type' => 'unparsed_content',
			'content' => '$1',
			'validate' => create_function('&$tag, &$data, $disabled', '		
				$data = vimeo_Main(trim(strtr($data, array(\'<br />\' => \'\'))));
			'),
			'disabled_content' => '$1',
			'block_level' => true,
			//'test' => '((?:https?\:\/\/)?(?:www\.)?vimeo\.com/(\d{1,12}))'
		);
	}

	/* The bbc button */
	function vimeo_bbc_add_button(&$buttons)
	{
		global $txt, $modSettings;
		
		loadLanguage('vimeo');

		if (empty($modSettings['vimeo_master']))
			return;
			
		$vimeo_bbc = array(
			'halves' => array(
				'first' => array_slice($buttons[1], 0, 2),
				'second' => array_slice($buttons[1], 2)
			),
			'insert' => array(
				'0' => array(
					'image' => 'vimeo',
					'code' => 'vimeo',
					'before' => '[vimeo]',
					'after' => '[/vimeo]',
					'description' => $txt['vimeo_desc']
				)
			)
		);
		unset($buttons[1]);
		$buttons[1] = array_merge($vimeo_bbc['halves']['first'], $vimeo_bbc['insert'], $vimeo_bbc['halves']['second']);
	}
	
	/* Take the url, take the video ID and return the embed code */
	function vimeo_Main($data)
	{
		global $modSettings, $txt;

		loadLanguage('vimeo');

		 /* Regex time */ 
		$pattern = '((?:https?\:\/\/)?(?:www\.)?\bvimeo\.com\b/(\d{1,12}))';

		if (preg_match($pattern, $data))
		{
			$data = preg_replace($pattern, '$1', $data);
			$data = vimeo_Replace($data);	
			return $data;
		}
		else
		{
			return sprintf($txt['vimeo_unvalid_url']);
		}	
	}
	
	/* A simple function to show the video with some parameters */
	function vimeo_Replace($string)
	{
		global $modSettings, $txt;

		loadLanguage('vimeo');
		
		/* check video ID */
		if (ctype_digit($string))
		{
			/* ID ok */
			/* check the user video controls , else use the default value then */
			$autoplay = empty($modSettings['vimeo_color']) ? '0' : $modSettings['vimeo_autoplay'];
			$badge = empty($modSettings['vimeo_color']) ? '1' : $modSettings['vimeo_badge'];
			$byline = empty($modSettings['vimeo_color']) ? '1' : $modSettings['vimeo_byline'];
			$loop = empty($modSettings['vimeo_color']) ? '0' : $modSettings['vimeo_loop'];
			$portrait = empty($modSettings['vimeo_color']) ? '1' : $modSettings['vimeo_portrait'];
			$video_title = empty($modSettings['vimeo_color']) ? '1' : $modSettings['vimeo_video_title'];
			$color = empty($modSettings['vimeo_color']) ? '00adef' : $modSettings['vimeo_color'];
			$width = empty($modSettings['vimeo_video_width']) ? '640' : $modSettings['vimeo_video_width'];
			$height = empty($modSettings['vimeo_video_height']) ? '360' : $modSettings['vimeo_video_height'];

			/* Return the HTML  */
			$return = '
			<iframe src="http://player.vimeo.com/video/'.$string.'?autoplay='.$autoplay.'?portrait=0&color='.$color.'?title='.$video_title.'?byline='.$byline.'?badge='.$badge.'?loop='.$loop.'" width="'.$width.'" height="'.$height.'" frameborder="0" webkitAllowFullScreen mozallowfullscreen allowFullScreen autoplay=1></iframe><br>
			';
			return $return;
		}
		/* ID wrong */
		else
		{
			return sprintf($txt['vimeo_unvalid_id']);
		}
	}
	/* DUH! WINNING! */
	function vimeo_bcc_copyright(&$dummy)
	{
		global $context;
		if (isset($context['current_action']) && $context['current_action'] == 'credits')
		$context['copyrights']['mods'][] = 'Vimeo Embedder BBC Mod | <a href="http://www.simplemachines.org/community/index.php?action=profile;u=314795" title="AdemaStudios">&copy 2012 - 2014 by Pipke</a>';
	}
